@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 use PlugAuth::Client;
 
 my $client = PlugAuth::Client->new;
